using Dakota.Data;
using Microsoft.Xna.Framework;
using Nez;

namespace Dakota.Renderables
{
    public class DialogBox : RenderableComponent, IUpdatable
    {
        public override float Width => 1000;
        public override float Height => 100;

        private const int Padding = 10;
        private const int PhotoBoxSize = 72;

        private float _durationRemaining;
        private VectorText _vt;
        private StaticBox _sb;

        public override void OnAddedToEntity()
        {
            RenderLayer = GameConstants.UiRenderLayerBg;
            _vt = Entity.AddComponent(new VectorText("", 20, GameConstants.SpaceUiColor));
            _vt.LocalOffset = new Vector2(Padding * 2 + PhotoBoxSize, Padding);

            _sb = Entity.AddComponent(new StaticBox(72, 72, GameConstants.SpaceCommandColor));
            _sb.LocalOffset = new Vector2(Padding, Padding);
        }

        public override void Render(Batcher batcher, Camera camera)
        {
            batcher.DrawRect(Entity.Position, Width, Height, GameConstants.ColorBlack);
            batcher.DrawHollowRect(Entity.Position, Width - 5, Height, GameConstants.SpaceUiColor);
            batcher.DrawHollowRect(Entity.Position.X + Padding, Entity.Position.Y + Padding,
                PhotoBoxSize, PhotoBoxSize, GameConstants.SpaceUiColor);
        }

        public void Update()
        {
            _durationRemaining -= Time.DeltaTime;
            if (_durationRemaining < 0)
            {
                Enabled = false;
                _vt.Enabled = false;
                _sb.Enabled = false;
            }
        }

        public void ShowDialog(string text, float duration)
        {
            _durationRemaining = duration;
            _vt.Text = text;
            _vt.Color = GameConstants.SpaceCommandColor;
            Enabled = true;
            _vt.Enabled = true;
            _sb.Enabled = true;
        }
    }
}