using Dakota.Data;
using Microsoft.Xna.Framework;
using Nez;

namespace Dakota.Space
{
    public class Projectile : RenderableComponent, IUpdatable
    {
        private float _duration;

        private bool _playerFired;
        private ProjectileType _type;
        private Vector2 _velocity;

        public Projectile(ProjectileType type, bool playerFired, float duration)
        {
            _type = type;
            _playerFired = playerFired;
            _duration = duration;
        }

        public override float Width => 2;
        public override float Height => 2;

        public void Update()
        {
            _duration -= Time.DeltaTime;
            if (_duration <= 0)
                Entity.Destroy();
        }

        public override void OnAddedToEntity()
        {
            _velocity = Entity.GetComponent<SpaceObject>().Velocity;

            Collider collider;
            switch (_type)
            {
                case ProjectileType.Bullet:
                    collider = Entity.AddComponent(new CircleCollider(1));
                    break;
                case ProjectileType.Beam:
                    collider = Entity.AddComponent(new PolygonCollider(new[]
                    {
                        new Vector2(0, 0),
                        _velocity * 2
                    }));
                    break;
                default:
                    collider = Entity.AddComponent(new CircleCollider(1));
                    break;
            }

            collider.IsTrigger = true;
        }

        public override void Render(Batcher batcher, Camera camera)
        {
            var color = _playerFired ? GameConstants.FriendlyWeaponColor : GameConstants.HostileWeaponColor;
            switch (_type)
            {
                case ProjectileType.Bullet:
                    batcher.DrawCircle(Entity.Position, 1, color);
                    break;
                case ProjectileType.Beam:
                    batcher.DrawLine(Entity.Position, Entity.Position + _velocity * 2, color);
                    break;
            }
        }
    }
}