using System.Reflection;
using Dakota.Data;
using Nez;

namespace Dakota.Space
{
    public class SpaceHudMap : RenderableComponent, IUpdatable
    {
        private const int Regions = 5;
        private int[,] _regionCount;
        private int _playerRegionX;
        private int _playerRegionY;
        public override float Width => 100;
        public override float Height => 100;

        // Rudimentary
        // System Scanner
        // System Scanner+

        public void Update()
        {
            var scene = (SpaceScene) Entity.Scene;
            _regionCount = new int[Regions, Regions];

            var xDiv = scene.CurrentZone.Width / Regions;
            var yDiv = scene.CurrentZone.Height / Regions;

            _playerRegionX = (int) (scene.Player.Position.X / xDiv);
            _playerRegionY = (int) (scene.Player.Position.Y / yDiv);

            // reset asteroid counts
            for (var i = 0; i < Regions; i++)
            for (var j = 0; j < Regions; j++)
                _regionCount[i, j] = 0;
            // count asteroids
            foreach (var asteroid in scene.FindComponentsOfType<Asteroid>())
            {
                var x = (int) (asteroid.Entity.Position.X / xDiv);
                var y = (int) (asteroid.Entity.Position.Y / yDiv);
                if (x < 0 || x >= Regions || y < 0 || y >= Regions)
                    continue;
                _regionCount[x, y] += 1;
            }
        }

        public override void Render(Batcher batcher, Camera camera)
        {
            var unitSize = (Height - 1) / Regions;

            batcher.DrawHollowRect(Entity.Position.X + LocalOffset.X,
                Entity.Position.Y + LocalOffset.Y,
                Width,
                Height,
                GameConstants.SpaceHudFontColor);


            for (var i = 0; i < Regions; i++)
            for (var j = 0; j < Regions; j++)
            {
                var color = GameConstants.ColorBlack;
                if (_regionCount[i, j] >= 1)
                    color = GameConstants.AsteroidColor;
                batcher.DrawRect(
                    Entity.Position.X + LocalOffset.X + unitSize * i,
                    Entity.Position.Y + LocalOffset.Y + unitSize * j,
                    unitSize,
                    unitSize,
                    color);
            }

            batcher.DrawRect(
                Entity.Position.X + LocalOffset.X + unitSize * _playerRegionX + 5,
                Entity.Position.Y + LocalOffset.Y + unitSize * _playerRegionY + 5,
                unitSize - 10,
                unitSize - 10,
                GameConstants.ShipColor);
        }
    }
}