using Lighthouse.Data;
using Nez;

namespace Lighthouse
{
    public enum WeatherType
    {
        Sun,
        Rain,
        Snow,
    }

    public class World : SceneComponent, IUpdatable
    {
        // space
        public Location Location;
        public bool IsIndoors => Location == Locations.Island;

        // time
        public const int DayInSeconds = 30;
        public const float Sunrise = 6;
        public int Day;
        public double DayTime;
        public int Hour => (int)DayTime;
        public Player Player;
        private double _lastDayStart = 0;
        
        // weather
        public WeatherType Weather;
        
        // minimap
        public bool[,] Shroud;

        public World()
        {
            Day = 0;
            Shroud = new bool[1000, 1000];
            Weather = WeatherType.Snow;
        }

        public override void Update()
        {
            if (_lastDayStart == 0)
            {
                _lastDayStart = Time.TotalTime;
            }

            DayTime = (Time.TotalTime - _lastDayStart) / DayInSeconds * 24;
            if (DayTime > 24)
            {
                DayTime -= 24;
                Day += 1;
                _lastDayStart = Time.TotalTime;
            }

            for (var x = Player.X - 20; x < Player.X + 20; x++)
            {
                for (var y = Player.Y - 10; y < Player.Y + 10; y++)
                {
                    Shroud[x, y] = true;
                }
            }
        }

        public string GetTileType(int x, int y)
        {
            // top down
            for(var i=Location.Map.Layers.Length-1; i >= 0; i--)
            {
                var layer = Location.Map.Layers[i];
                if (y < 0 || x < 0 || x >= layer.width || y >= layer.height)
                    continue;
                int gid = layer.data[x + (y * layer.width)];
                if (gid == 0)
                    continue;
                var mapTileset = Location.Map.GetTiledMapTileset(gid);
                var tileset = Location.Tilesets[mapTileset.firstgid];
                var tile = Location.Map.GetTiledTile(mapTileset, tileset, gid);
                if (tile?.type != null)
                    return tile.type;
            }
            return "";
        }
    }
}