using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Nez;
using Nez.BitmapFonts;

namespace Lighthouse
{
    public class Menu : RenderableComponent
    {
        private string[] _options;
        private Vector2[] _offsets;
        private int _selection = 0;

        public override float Width => 640;
        public override float Height => 360;

        public int Selection
        {
            get => _selection;
            set
            {
                if (value <= 0)
                {
                    _selection = 0; 
                } 
                else if(value >= _options.Length)
                {
                    _selection = _options.Length - 1;
                }
                else
                {
                    _selection = value;
                }
            }
        }
        
        public Menu(string[] options)
        {
            _options = options;

            // compute word spacing
            var totalFontHeight = 0f;
            _offsets = new Vector2[options.Length];
            for(var i=0; i < options.Length; i++)
            {
                var m = Graphics.Instance.BitmapFont.MeasureString(options[i]);
                _offsets[i] = new Vector2((Width - m.X) / 2, totalFontHeight);
                totalFontHeight += m.Y;
            }

            var addYPadding = (Height - totalFontHeight) / options.Length;
            for(var i=0; i < options.Length; i++)
            {
                _offsets[i].Y += addYPadding*i;
            }
        }

        public override void Render(Batcher batcher, Camera camera)
        {
            for(int i=0; i < _options.Length; i++)
                batcher.DrawString(Graphics.Instance.BitmapFont, _options[i], _offsets[i],
                    i == Selection ? Color.GreenYellow : Color.Green);
        }

        public virtual void OnSelection()
        {
            Console.WriteLine($"Option Selected: {Selection}: {_options[Selection]}");
        }
    }

}